# ListDesktopResourcesResponse

Response object for listing DesktopResource objects.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**limit** | **int** | The maximum number of records returned in the response. | 
**desktop_resources** | [**[DesktopResource]**](DesktopResource.md) | List of DesktopResource objects. | [optional] 
**page_at_id** | **str** | The id to request in the pagination query to get the next page. | [optional] 
**page_info** | [**PageInfo**](PageInfo.md) |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


